import cv2
import matplotlib.pyplot as plt
import numpy as np

# image
img = cv2.imread("datai_team.jpg",0)
plt.figure()
plt.imshow(img, cmap="gray")
plt.axis("off")

plt.title("Original Image")

# erosion
# https://docs.opencv.org/trunk/d9/d61/tutorial_py_morphological_ops.html
# it erodes away the boundaries of foreground object
kernel = np.ones((5,5), dtype = np.uint8)
result = cv2.erode(img, kernel, iterations = 1) # iteration = 1 demek bunu 1 kere yap demek
plt.figure()
plt.imshow(result, cmap="gray")
plt.axis("off")
plt.title("Erozyon")

# dilation genişleme
# erosion is followed by dilation. Because, erosion removes white noises, but it also shrinks our object. 
# So we dilate it. Since noise is gone, they won't come back, but our object area increases.
result = cv2.dilate(img, kernel, iterations = 1) # iteration = 1 demek bunu 1 kere yap demek
plt.figure()
plt.imshow(result, cmap="gray")
plt.axis("off")

plt.title("Genişleme")

# white noise
whiteNoise = np.random.randint(low = 0, high = 2, size = img.shape[:2])
whiteNoise = whiteNoise*255
plt.figure()
plt.imshow(whiteNoise, cmap = "gray")
plt.axis("off")

noise_img = whiteNoise + img
plt.figure()
plt.imshow(noise_img,cmap = "gray")
plt.axis("off")


# Opening is just another name of erosion followed by dilation.
opening = cv2.morphologyEx(noise_img.astype(np.float32), cv2.MORPH_OPEN, kernel)
plt.figure()
plt.imshow(opening,cmap = "gray")
plt.axis("off")

plt.title("Genişleme")

# kapatma
blackNoise = np.random.randint(low = 0, high = 2, size = img.shape[:2])
blackNoise = blackNoise*-255
black_noise_img = blackNoise + img
plt.figure()
plt.imshow(black_noise_img, cmap = "gray")
plt.axis("off")

black_noise_img[black_noise_img <= -245] = 0
plt.figure()
plt.imshow(black_noise_img, cmap = "gray")
plt.axis("off")

closing = cv2.morphologyEx(black_noise_img.astype(np.float32), cv2.MORPH_CLOSE, kernel)
plt.figure()
plt.imshow(closing,cmap = "gray")
plt.axis("off")

plt.title("Kapatma")

# Morphological Gradient it is edge detection
# It is the difference between dilation and erosion of an image.
gradient = cv2.morphologyEx(img, cv2.MORPH_GRADIENT, kernel)
plt.figure()
plt.imshow(gradient,cmap = "gray")
plt.axis("off")
plt.title("Morfolojik  Gradyan")






